#[non_exhaustive]pub enum UnexpectedField {
String(EditableFieldString),
ConcealedString(EditableFieldConcealedString),
Boolean(EditableFieldBoolean),
Date(EditableFieldDate),
YearMonth(EditableFieldYearMonth),
SubdivisionCode(EditableFieldSubdivisionCode),
CountryCode(EditableFieldCountryCode),
WifiNetworkSecurityType(EditableFieldWifiNetworkSecurityType),
Email(EditableFieldEmail),
Number(EditableFieldNumber),
Unknown {
field_type: FieldType,
value: String,
},
}Expand description
A field of the incorrect type that was passed instead of an expected field type.
For example if the spec requires a string type, but the user passes in
concealed-string instead.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
String(EditableFieldString)
ConcealedString(EditableFieldConcealedString)
Boolean(EditableFieldBoolean)
Date(EditableFieldDate)
YearMonth(EditableFieldYearMonth)
SubdivisionCode(EditableFieldSubdivisionCode)
CountryCode(EditableFieldCountryCode)
WifiNetworkSecurityType(EditableFieldWifiNetworkSecurityType)
Email(EditableFieldEmail)
Number(EditableFieldNumber)
Unknown
Implementations
Sourceimpl UnexpectedField
impl UnexpectedField
Sourcepub fn field_type(&self) -> FieldType
pub fn field_type(&self) -> FieldType
Returns the FieldType for this value.