pub struct Account<E = ()> {
pub id: B64Url,
pub username: String,
pub email: String,
pub full_name: Option<String>,
pub collections: Vec<Collection<E>>,
pub items: Vec<Item<E>>,
pub extensions: Option<Vec<Extension<E>>>,
}Fields
id: B64UrlA unique identifier for the Account which is machine generated and an opaque byte sequence with a maximum size of 64 bytes. It SHOULD NOT to be displayed to the user.
username: StringA pseudonym defined by the user to name their account. If none is set, this should be an empty string.
email: StringThe email used to register the account in the previous provider.
full_name: Option<String>This field holds the user’s full name.
collections: Vec<Collection<E>>All the collections this account owns. If the user has collections that were shared with them by another account, it MUST NOT be present in this list.
items: Vec<Item<E>>All items that this account owns. If the user has access to items that were shared with them by another account, it MUST NOT be present in this list.
extensions: Option<Vec<Extension<E>>>This field contains all the extensions to the Account’s attributes.