pub struct AndroidAppCertificateFingerprint {
pub fingerprint: B64Url,
pub hash_alg: AndroidAppHashAlgorithm,
}Fields
fingerprint: B64UrlThis is the hash of the application’s public certificate using the hashing algorithm defined in AndroidAppCertificateFingerprint::hash_alg. The bytes of the hash are then encoded into base64url directly.
hash_alg: AndroidAppHashAlgorithmThe algorithm used to hash the AndroidAppCertificateFingerprint::fingerprint. This SHOULD be of value AndroidAppHashAlgorithm.