pub struct ApiKeyCredential<E = ()> {
pub key: Option<EditableField<EditableFieldConcealedString, E>>,
pub username: Option<EditableField<EditableFieldString, E>>,
pub key_type: Option<EditableField<EditableFieldString, E>>,
pub url: Option<EditableField<EditableFieldString, E>>,
pub valid_from: Option<EditableField<EditableFieldDate, E>>,
pub expiry_date: Option<EditableField<EditableFieldDate, E>>,
}Expand description
A ApiKeyCredential contains information to interact with an Application’s Programming Interface (API).
Fields
key: Option<EditableField<EditableFieldConcealedString, E>>This member denotes the key to communicate with the API.
username: Option<EditableField<EditableFieldString, E>>This member denotes the username associated with the key.
key_type: Option<EditableField<EditableFieldString, E>>This member denotes the type of the API key, such as bearer token or JSON Web Token. It is flexible to allow any type and not restrict it to a set list of types.
url: Option<EditableField<EditableFieldString, E>>This member denotes the url the API key is used with and SHOULD conform to the URL Standard.
valid_from: Option<EditableField<EditableFieldDate, E>>This member denotes the date the API key is valid from.
expiry_date: Option<EditableField<EditableFieldDate, E>>This member denotes the date on which the API key expires.