pub struct BasicAuthCredential<E = ()> {
pub username: Option<EditableField<EditableFieldString, E>>,
pub password: Option<EditableField<EditableFieldConcealedString, E>>,
}Expand description
A BasicAuthCredential contains a username/password login credential. Can either represent a Basic access authentication or a form on a web page.
A BasicAuthCredential SHOULD have an accompanying super::CredentialScope in the credentials array. This indicates in which websites or applications these fields SHOULD be presented.
Fields
username: Option<EditableField<EditableFieldString, E>>The username associated with the credential.
password: Option<EditableField<EditableFieldConcealedString, E>>The password associated with the credential.