Collection

Struct Collection 

pub struct Collection<E = ()> {
    pub id: B64Url,
    pub creation_at: Option<u64>,
    pub modified_at: Option<u64>,
    pub title: String,
    pub subtitle: Option<String>,
    pub items: Vec<LinkedItem>,
    pub sub_collections: Option<Vec<Collection<E>>>,
    pub extensions: Option<Vec<Extension<E>>>,
}

Fields

id: B64Url

A unique identifier for the Collection which is machine generated and an opaque byte sequence with a maximum size of 64 bytes. It SHOULD NOT be displayed to the user.

creation_at: Option<u64>

This member contains the UNIX timestamp in seconds at which this Collection was originally created. If this member is not set, but the importing provider requires this member in their proprietary data model, the importer SHOULD use the current timestamp at the time the provider encounters this 8Collection].

modified_at: Option<u64>

This member contains the UNIX timestamp in seconds of the last modification brought to this Collection. If this member is not set, but the importing provider requires this member in their proprietary data model, the importer SHOULD use the current timestamp at the time the provider encounters this Collection.

title: String

The display name of the Collection.

subtitle: Option<String>

This field is a subtitle or a description of the Collection.

items: Vec<LinkedItem>

Enumerates all the LinkedItem in this Collection. A LinkedItem contains the necessary data to indicate which Items are part of this Collection.

sub_collections: Option<Vec<Collection<E>>>

Enumerates any sub-collections if the provider supports recursive organization.

extensions: Option<Vec<Extension<E>>>

This enumeration contains all the extensions to the Collection’s attributes.