pub struct CredentialScope {
pub urls: Vec<String>,
pub android_apps: Vec<AndroidAppIdCredential>,
}Expand description
This is an object that describes an appropriate context in which the Item’s crate::Item::credentials can to be used.
Fields
urls: Vec<String>This member holds strings which SHOULD follow the Uniform Resource Identifier (URI) syntax as defined in RFC3986.
android_apps: Vec<AndroidAppIdCredential>This member defines the android apps that have been validated to be appropriate for the credentials to be used.