pub struct CustomFieldsCredential<E = ()> {
pub id: Option<B64Url>,
pub label: Option<String>,
pub fields: Vec<EditableFieldValue<E>>,
pub extensions: Vec<Extension<E>>,
}Fields
id: Option<B64Url>A unique identifier for the CustomFields. It MUST be a machine-generated opaque byte sequence with a maximum size of 64 bytes. It SHOULD NOT be displayed to the user.
label: Option<String>This member is a human-palatable title to describe the section. This value MAY be set by the credential owner.
fields: Vec<EditableFieldValue<E>>The collection of miscellaneous fields under this section.
extensions: Vec<Extension<E>>This member permits the exporting provider to add additional information associated to this CustomFields. This MAY be used to provide an exchange where a minimal amount of information is lost.