pub struct Expected<T>(/* private fields */);Expand description
Holds onto an editable field, and records whether it was an expected or unexpected field.
This is used as a type-safe wrapper around an editable field to encode expectations around the type of field we are expecting in a credential.
This can only be instantiated via the exposed From implementation so that newly
constructed credentials remain spec-compliant with regards to their fields.
Implementations
Sourceimpl<T> Expected<T>where
T: EditableFieldType,
impl<T> Expected<T>where
T: EditableFieldType,
Sourcepub fn field_type(&self) -> FieldType
pub fn field_type(&self) -> FieldType
Returns the real FieldType of this field.
Sourcepub fn as_expected(&self) -> Result<&T, &UnexpectedField>
pub fn as_expected(&self) -> Result<&T, &UnexpectedField>
Tries to return the field type we were expecting.
Sourcepub fn into_expected(self) -> Result<T, UnexpectedField>
pub fn into_expected(self) -> Result<T, UnexpectedField>
Tries to return the field type we were expecting as an owned type.