pub struct Header<E = ()> {
pub version: Version,
pub exporter_rp_id: String,
pub exporter_display_name: String,
pub timestamp: u64,
pub accounts: Vec<Account<E>>,
}Fields
version: VersionThe version of the format definition contained within this exchange payload. The version MUST correspond to a published level of the CXF standard.
exporter_rp_id: StringThe name of the exporting app as a relying party identifier.
exporter_display_name: StringThe display name of the exporting app to be presented to the user.
timestamp: u64The UNIX timestamp during at which the export document was completed.
accounts: Vec<Account<E>>The list of Accounts being exported.