Item

Struct Item 

pub struct Item<E = ()> {
    pub id: B64Url,
    pub creation_at: Option<u64>,
    pub modified_at: Option<u64>,
    pub title: String,
    pub subtitle: Option<String>,
    pub favorite: Option<bool>,
    pub scope: Option<CredentialScope>,
    pub credentials: Vec<Credential<E>>,
    pub tags: Option<Vec<String>>,
    pub extensions: Option<Vec<Extension<E>>>,
}

Fields

id: B64Url

A unique identifier for the Item which is machine generated and an opaque byte sequence with a maximum size of 64 bytes. It SHOULD NOT be displayed to the user.

creation_at: Option<u64>

The member contains the UNIX timestamp in seconds at which this item was originally created. If this member is not set, but the importing provider requires this member in their proprietary data model, the importer SHOULD use the current timestamp at the time the provider encounters this Item.

modified_at: Option<u64>

This member contains the UNIX timestamp in seconds of the last modification brought to this Item. If this member is not set, but the importing provider requires this member in their proprietary data model, the importer SHOULD use the current timestamp at the time the provider encounters this Item.

title: String

This member’s value is the user-defined name or title of the item.

subtitle: Option<String>

This member is a subtitle or description for the Item.

favorite: Option<bool>

This member denotes whether the user has marked the Item as a favorite to easily present in the UI.

scope: Option<CredentialScope>

This member defines the scope where the Item::credentials SHOULD be presented. The credentials SHOULD only be presented within this scope unless otherwise specified by a specific Credential type.

credentials: Vec<Credential<E>>

This member contains a set of Credentials that SHOULD be associated to the type.

tags: Option<Vec<String>>

This member contains user-defined tags that they may use to organize the item.

extensions: Option<Vec<Extension<E>>>

This member contains all the extensions the exporter MAY have to define the Item type that is being exported to be as complete of an export as possible.