ItemReferenceCredential

Struct ItemReferenceCredential 

pub struct ItemReferenceCredential {
    pub reference: LinkedItem,
}
An ItemReferenceCredential is a pointer to another Item, denoting that the two items MAY be logically linked together.

Fields

reference: LinkedItem

A LinkedItem which references another Item.

Note: The other item SHOULD be in the exchange if it is owned by the same Account. However, the other item MAY NOT be in the exchange if it is owned by a different account and shared with the currenly exchanged account.