LinkedItem

Struct LinkedItem 

pub struct LinkedItem {
    pub item: B64Url,
    pub account: Option<B64Url>,
}

Fields

item: B64Url

The Item’s id that this LinkedItem refers to. Note that this Item might not be sent as part of the current exchange.

account: Option<B64Url>

This member indicates the Account’s id the referenced Item belongs to. If not present, the Item belongs to the current Account being exchanged.