PasskeyCredential

Struct PasskeyCredential 

pub struct PasskeyCredential {
    pub credential_id: B64Url,
    pub rp_id: String,
    pub username: String,
    pub user_display_name: String,
    pub user_handle: B64Url,
    pub key: B64Url,
    pub fido2_extensions: Option<Fido2Extensions>,
}
Passkey

Note: Passkeys using a non-zero signature counter MUST be excluded from the export and the exporter SHOULD inform the user that such passkeys are excluded from the export. Importers MUST set a zero value for the imported passkey signature counters and MUST NOT increment them after the fact.

Fields

credential_id: B64Url

This member contains a WebAuthn Credential ID which uniquely identifies the passkey instance. The decoded raw value MUST be equal to the value given in PublicKeyCredential’s rawId field during registration.

rp_id: String

This member specifies the WebAuthn Relying Party Identifier to which the passkey instance is tied to. The value MUST be equal to the RP ID that was defined by the authenticator during credential registration.

username: String

This member contains a human-palatable identifier for the user account to which the passkey instance is tied to. The value SHOULD be equal to the value in PublicKeyCredentialUserEntity’s name member given to the authenticator during registration.

The only case where the value MAY not be the one set during registration is if the exporting provider allows the user to edit their username. In such a case, the value of this field MUST be the user edited value. See  3.3.3.1 Editability of passkey fields for more details.

user_display_name: String

This member contains a human-palatable identifier for the user account, intended only for display. The value SHOULD be equal to the value in PublicKeyCredentialUserEntity’s displayName member given to the authenticator during registration.

The only case where the value MAY not be the one set during registration is if the exporting provider allows the user to edit their username. In such a case, the value of this field MUST be the user edited value. See  3.3.3.1 Editability of passkey fields for more details.

user_handle: B64Url

This member contains the user handle which is the value used to identify the user account associated to this passkey instance. The value MUST be equal to the value in PublicKeyCredentialUserEntity’s id member given to the authenticator during registration.

key: B64Url

The private key associated to this passkey instance. The value MUST be PKCS#8 ASN.1 DER formatted byte string which is then Base64url encoded. The value MUST give the same public key value that was provided by the original authenticator during registration.

fido2_extensions: Option<Fido2Extensions>

This member denotes the WebAuthn or CTAP2 extensions that are associated to this passkey instance.