pub struct SharedExtension {
pub accessors: Vec<SharingAccessor>,
}Expand description
Defines entity sharing between user accounts
Entities are shared by applying the SharedExtension extension to them.
This extensions MUST only be applied to Collection and Item.
Entities that are shared MUST only be included in the exports for accounts that are credential owners or admins of the entity.
Fields
accessors: Vec<SharingAccessor>A list of SharingAccessor objects that represents users or groups
and their permissions with respect to access on the entity to which the SharedExtension
is applied.