SharingAccessor

Struct SharingAccessor 

pub struct SharingAccessor {
    pub ty: SharingAccessorType,
    pub account_id: B64Url,
    pub name: String,
    pub permissions: Vec<SharingAccessorPermission>,
}
A SharingAccessor represents a user or group and their access permissions with respect to an entity.

Fields

ty: SharingAccessorType

Indicates the type of accessor for which permissions are defined. Importers must ignore any SharingAccessor entries when this value is SharingAccessorType::Unknown.

account_id: B64Url

This member specifies the Account, identified by its Account::id, that has been given access to the shared entity by the current exporting Account.

name: String

This contains the accessor’s account name. If Self::ty has the value SharingAccessorType::User this SHOULD be set to the Account::username. If Self::ty has the value SharingAccessorType::Group this SHOULD be set to the group’s name.

permissions: Vec<SharingAccessorPermission>

The list of permissions that Account defined by Self::account_id has with respect to access on the shared entity. Importers MUST ignore entries with value of SharingAccessorPermission::Unknown. Importers MUST ignore any [`SharingAccessors=] that have an empty permissions list, whether it’s been exported as empty or when it’s empty as a result of ignoring all unknown entries.