pub struct EditableField<T, E = ()> {
pub id: Option<B64Url>,
pub value: T,
pub label: Option<String>,
pub extensions: Option<Vec<Extension<E>>>,
}Fields
id: Option<B64Url>A unique identifier for the EditableField which is machine generated and an opaque byte sequence with a maximum size of 64 bytes. It SHOULD NOT be displayed to the user.
value: TThis member contains the fieldType defined by the user.
label: Option<String>This member contains a user facing value describing the value stored. This value MAY be user defined.
extensions: Option<Vec<Extension<E>>>This member permits the exporting provider to add additional information associated to this EditableField. This MAY be used to provide an exchange where a minimal amount of information is lost.