pub struct FileCredential {
pub id: B64Url,
pub name: String,
pub decrypted_size: u64,
pub integrity_hash: B64Url,
}Expand description
A FileCredential acts as a placeholder to an arbitrary binary file holding its associated metadata. When an importing provider encounters a file credential, they MAY request the file afterwards if they have a direct exchange. If the exchange will produce an export response file, then the associated encrypted file MUST be stored in the documents folder of the zip archive.
Fields
id: B64UrlThe file’s identifier, used as the file name in the zip archive.
name: StringThe file name with the file extension if applicable.
decrypted_size: u64The file’s decrypted size in bytes.
integrity_hash: B64UrlThe SHA256 hash of the decrypted file. This hash MUST be used by the importing provider when the file is decrypted to ensure that it has not been corrupted.