IdentityDocumentCredential

Struct IdentityDocumentCredential 

pub struct IdentityDocumentCredential<E = ()> {
    pub issuing_country: Option<EditableField<EditableFieldCountryCode, E>>,
    pub document_number: Option<EditableField<EditableFieldString, E>>,
    pub identification_number: Option<EditableField<EditableFieldString, E>>,
    pub nationality: Option<EditableField<EditableFieldString, E>>,
    pub full_name: Option<EditableField<EditableFieldString, E>>,
    pub birth_date: Option<EditableField<EditableFieldDate, E>>,
    pub birth_place: Option<EditableField<EditableFieldString, E>>,
    pub sex: Option<EditableField<EditableFieldString, E>>,
    pub issue_date: Option<EditableField<EditableFieldDate, E>>,
    pub expiry_date: Option<EditableField<EditableFieldDate, E>>,
    pub issuing_authority: Option<EditableField<EditableFieldString, E>>,
}
An IdentityDocumentCredential is for any document, card, or number identifying a person or entity. Examples include national ID cards, Social Security Numbers (SSN), Tax Identification Numbers (TIN), health insurance cards, or Value-Added Tax (VAT) numbers.

Credentials like the SSN can still be encoded as an IdentityDocument by only providing the identificationNumber field, since the others are generally considered to be undefined in its case.

Note: Driver’s licenses and passports may be accepted as identity verification in some countries, but they are specified separately in the DriversLicenseCredential and PassportCredential types, respectively.

Fields

issuing_country: Option<EditableField<EditableFieldCountryCode, E>>

The document’s issuing country. This MUST conform to the ISO 3166-1 alpha-2 format.

document_number: Option<EditableField<EditableFieldString, E>>

The document’s identifying number. This identifying number is tied to the issuance of the document and is expected to change upon its reissuance, even when the person’s information might remain the same.

identification_number: Option<EditableField<EditableFieldString, E>>

The person’s or other entity’s identification number. This identifying number is generally expected to remain stable across reissuances of the identity document itself. For identification numbers that are not an identity document (e.g., SSN, TIN, or VAT), this field is generally the only one that’s expected to be present in the credential.

nationality: Option<EditableField<EditableFieldString, E>>

The person’s nationality.

full_name: Option<EditableField<EditableFieldString, E>>

The person’s full name.

birth_date: Option<EditableField<EditableFieldDate, E>>

The person’s date of birth.

birth_place: Option<EditableField<EditableFieldString, E>>

The person’s place of birth.

sex: Option<EditableField<EditableFieldString, E>>

The person’s sex or gender.

issue_date: Option<EditableField<EditableFieldDate, E>>

The date on which the document was issued.

expiry_date: Option<EditableField<EditableFieldDate, E>>

The date on which the document expires.

issuing_authority: Option<EditableField<EditableFieldString, E>>

The official body or government agency responsible for issuing the document.